//
//  ImgCollectionViewController.m
//  ImgPicker_storyboard
//
//  Created by 王宇宙 on 2016/7/14.
//  Copyright © 2016年 王宇宙. All rights reserved.
//

#import "ImgCollectionViewController.h"
#import <AssetsLibrary/AssetsLibrary.h>
#import "AssetModel.h"
#import "ImgPickerNavigationController.h"
#import "ImgPreviewCollectionView.h"
#import "ImgCollectionViewCell.h"

#define MARGIN 10
#define COL 4
#define kWidth [UIScreen mainScreen].bounds.size.width

@interface ImgCollectionViewController ()

@property (nonatomic,strong) NSMutableArray *assetModels;
//选中的模型
@property (nonatomic,strong) NSMutableArray *selectedModels;
//选中的图片
@property (nonatomic,strong) NSMutableArray *selectedImages;

@end

@implementation ImgCollectionViewController

- (NSMutableArray *)assetModels{
    if (_assetModels == nil) {
        _assetModels = [NSMutableArray array];
    }
    return _assetModels;
}
- (NSMutableArray *)selectedImages{
    if (_selectedImages == nil) {
        _selectedImages = [NSMutableArray array];
    }
    return _selectedImages;
}
- (NSMutableArray *)selectedModels{
    if (_selectedModels == nil) {
        _selectedModels = [NSMutableArray array];
    }
    return _selectedModels;
}
- (void)setGroup:(ALAssetsGroup *)group{
    _group = group;
    [group enumerateAssetsUsingBlock:^(ALAsset *asset, NSUInteger index, BOOL *stop) {
        if (asset == nil) return ;
        if (![[asset valueForProperty:ALAssetPropertyType] isEqualToString:ALAssetTypePhoto]) {//不是图片
            return;
        }
        AssetModel *model = [[AssetModel alloc] init];
        model.thumbnail = [UIImage imageWithCGImage:asset.thumbnail];
        model.imgUrl = asset.defaultRepresentation.url;
        [self.assetModels addObject:model];
    }];
}
- (void)viewDidLoad {
    [super viewDidLoad];
    
    
    //
    UICollectionViewFlowLayout *flowLayout = [[UICollectionViewFlowLayout alloc] init];
    flowLayout.minimumLineSpacing = MARGIN;
    flowLayout.minimumInteritemSpacing = MARGIN;
    CGFloat cellHeight = (kWidth - (COL + 1) * MARGIN) / COL;
    flowLayout.itemSize = CGSizeMake(cellHeight, cellHeight);
    flowLayout.sectionInset = UIEdgeInsetsMake(10, 10, 10, 10);
    [self.collectionView setCollectionViewLayout:flowLayout];
    //右侧完成按钮
    UIBarButtonItem *finish = [[UIBarButtonItem alloc] initWithTitle:@"完成" style:UIBarButtonItemStylePlain target:self action:@selector(finishSelecting)];
    self.navigationItem.rightBarButtonItem = finish;
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

//出口,选择完成图片
- (void)finishSelecting{
    
    if ([self.navigationController isKindOfClass:[ImgPickerNavigationController class]]) {
        ImgPickerNavigationController *picker = (ImgPickerNavigationController *)self.navigationController;
        if (picker.selectOriginals || picker.selectThumbnails) {
            
            for (AssetModel *model in self.assetModels) {
                if (model.isSelect) {
                    [self.selectedModels addObject:model];
                }
            }
            
            //获取原始图片可能是异步的,因此需要判断最后一个,然后传出
            for (int i = 0; i < self.selectedModels.count; i++) {
                AssetModel *model = self.selectedModels[i];
                [model originalImg:^(UIImage *image) {
                    [self.selectedImages addObject:image];
                    
                    if ( i == self.selectedModels.count - 1) {//最后一个
                        if (picker.selectOriginals) {
                            picker.selectOriginals(self.selectedImages);
                        }
                        
                    }
                }];
            }
            
            if (picker.selectThumbnails) {
                picker.selectThumbnails([_selectedModels valueForKeyPath:@"thumbnail"]);
            }
            
        }
    }
    
    //移除
    [self dismissViewControllerAnimated:YES completion:nil];
    
}
#pragma mark <UICollectionViewDataSource>

- (NSInteger)collectionView:(UICollectionView *)collectionView numberOfItemsInSection:(NSInteger)section {
    
    return self.assetModels.count;
    
}

- (UICollectionViewCell *)collectionView:(UICollectionView *)collectionView cellForItemAtIndexPath:(NSIndexPath *)indexPath {
    ImgCollectionViewCell *cell = [collectionView dequeueReusableCellWithReuseIdentifier:@"cell" forIndexPath:indexPath];
    AssetModel *model = self.assetModels[indexPath.item];
    cell.backIv.image = model.thumbnail;
    [cell.selectBtn setTitle:@"NO" forState:UIControlStateNormal];
    [cell.selectBtn setTitle:@"YES" forState:UIControlStateSelected];
    [cell.selectBtn addTarget:self action:@selector(buttonClicked:) forControlEvents:UIControlEventTouchUpInside];
    cell.selectBtn.tag = indexPath.item;//重新绑定
    cell.selectBtn.selected = model.isSelect;//恢复设定状态
    return cell;
}
- (void)buttonClicked:(UIButton *)sender{
    sender.selected = !sender.selected;
    AssetModel *model = self.assetModels[sender.tag];
    
    if (sender.selected == YES) {
        model.isSelect = YES;
    }
    else{
        model.isSelect = NO;
    }
}
-(void)collectionView:(UICollectionView *)collectionView didSelectItemAtIndexPath:(NSIndexPath *)indexPath{
    ImgCollectionViewCell* cell=(ImgCollectionViewCell*)[collectionView cellForItemAtIndexPath:indexPath];
    CGRect previousFrame=[self.collectionView convertRect:cell.frame toView:self.view];
    
    ImgPreviewCollectionView *browser = [[ImgPreviewCollectionView alloc] initWithFrame:previousFrame];
    browser.assetModels = self.assetModels;
    browser.currentIndex = indexPath.item;
    browser.previousFrame=previousFrame;
    [browser show];
}

@end
